@@ -5,9 +5,9 @@
 */
 
 #include "journalprint.h"
+#include "calendarsupport_debug.h"
 #include "utils.h"
 #include <KConfigGroup>
-#include "calendarsupport_debug.h"
 
 using namespace CalendarSupport;
 
@@ -22,8 +22,7 @@ QWidget *CalPrintJournal::createConfigWidget(QWidget *w)
 
 void CalPrintJournal::readSettingsWidget()
 {
-    auto *cfg
-        = dynamic_cast<CalPrintJournalConfig *>((QWidget *)mConfigWidget);
+    auto *cfg = dynamic_cast<CalPrintJournalConfig *>((QWidget *)mConfigWidget);
     if (cfg) {
         mFromDate = cfg->mFromDate->date();
         mToDate = cfg->mToDate->date();
@@ -33,8 +32,7 @@ void CalPrintJournal::readSettingsWidget()
 
 void CalPrintJournal::setSettingsWidget()
 {
-    auto *cfg
-        = dynamic_cast<CalPrintJournalConfig *>((QWidget *)mConfigWidget);
+    auto *cfg = dynamic_cast<CalPrintJournalConfig *>((QWidget *)mConfigWidget);
     if (cfg) {
         cfg->mFromDate->setDate(mFromDate);
         cfg->mToDate->setDate(mToDate);
@@ -78,8 +76,7 @@ void CalPrintJournal::saveConfig()
 void CalPrintJournal::setDateRange(const QDate &from, const QDate &to)
 {
     CalPrintPluginBase::setDateRange(from, to);
-    auto *cfg
-        = dynamic_cast<CalPrintJournalConfig *>((QWidget *)mConfigWidget);
+    auto *cfg = dynamic_cast<CalPrintJournalConfig *>((QWidget *)mConfigWidget);
     if (cfg) {
         cfg->mFromDate->setDate(from);
         cfg->mToDate->setDate(to);
